{ LOWVISC_FULL.PDE

  This example is a modification of the LOWVISC.PDE problem, in which the
  full domain has been modeled.  It writes flow data for the problem
  COUPLED_CONTAMINANT.PDE.

}

title 'Viscous flow in 2D channel, Re > 40'

select errlim = 0.005

variables
   u(0.1)
   v(0.01)
   p(1)

definitions
   Lx = 5       Ly = 1.5
   p0 = 2
   speed2 = u^2+v^2
   speed = sqrt(speed2)
   dens = 1
   visc = 0.04
   vxx = (p0/(2*visc*(2*Lx)))*(Ly-y)^2	{ open-channel x-velocity }

   rball=0.4
   cut = 0.1	{ value for bevel at the corners of the obstruction }

   penalty = 100*visc/rball^2
   Re = globalmax(speed)*(Ly/2)/(visc/dens)

initial values
   u = 0.5*vxx  v = 0  p = p0*x/(2*Lx)

equations
   u:  visc*div(grad(u)) - dx(p) = dens*(u*dx(u) + v*dy(u))
   v:  visc*div(grad(v)) - dy(p) = dens*(u*dx(v) + v*dy(v))
   p:  div(grad(p)) = penalty*(dx(u)+dy(v))

boundaries
   region 1
      start(-Lx,-Ly)
      value(u) = 0   value(v) = 0   load(p) = 0
      	line to (Lx,-Ly)

      load(u) = 0  value(v) = 0  value(p) = p0
      mesh_spacing=Ly/20
	  	line to (Lx,Ly)

      value(u) = 0  value(v) = 0  load(p) = 0
      mesh_spacing=100
		line to(-Lx,Ly)

      load(u) = 0  value(v) = 0  value(p) = 0
        line to close
      
   exclude
      start(Lx/2-rball,0)
      value(u)=0  value(v)=0  load(p)= 0
       	line to (Lx/2-rball,-rball) bevel(cut)
             to (Lx/2+rball,-rball) bevel(cut)
             to (Lx/2+rball,rball) bevel(cut)
             to (Lx/2-rball,rball) bevel(cut)
        	 to close

monitors
   contour(speed)  report(Re)

plots
   contour(u)  report(Re)
   contour(v)  report(Re)
   contour(speed) painted  report(Re)
   vector(u,v) as "flow"   report(Re)
   contour(p)  as "Pressure" painted
   contour(dx(u)+dy(v)) as "Continuity Error"
   elevation(u) from (-Lx,-Ly) to (-Lx,Ly)
   elevation(u) from (0,-Ly) to (0,Ly)
   elevation(u) from (Lx/2,-Ly) to (Lx/2,Ly)
   elevation(u) from (Lx,-Ly) to (Lx,Ly)

   transfer(u,v,p)  { write flow solution as initial conditions for "Coupled_Contaminant.pde" }

end "DD3bbs2ZityRNlFDmk2iy8uwuKJbTM71pJ7x6wxLIGyG4qQHWaip9JPLtHHO+YREyN0oI+0fb/BJ2YzkmhCbNplUzP6f/s1Ptgw1vc00lN1/OAtoifH1OgChCQo2BxCXkcjkf47yXs38s+MhfWbLUkpREFgBsDFGPXmhCpUsa0e"
