{  RICHARDS.PDE

  A solution of Richards' equation in 1D.
  Constant negative head at surface, unit gradient at bottom.
  This problem runs slowly, because the very steep wave front
  requires small cells and small timesteps to track accurately.

  submitted by Neil Soicher of University of Hawaii.
}

title "1-D Richard's equation"

coordinates
    cartesian1('y')

variables
    h (1)

definitions
    thr = 0.2
    ths = 0.58
    alpha = .08
    n = 1.412
    ks = 10
    {Using Van Genuchten parameters for water content (wc),
     water capacitance (C=d(wc)/dh), effecive saturation (se),
     and hydraulic Conductivity (k) }
    m  = 1-1/n
    wc = if h<0 then thr+(ths-thr)*(1+(abs(alpha*h))^n)^(-m) else ths
    C  = ((1-n)*abs(-alpha*h)^n*(1+abs(-alpha*h)^n)^((1/n)-2)*(ths-thr))/h
    se = (wc-thr)/(ths-thr)
    k  = ks*sqrt(se)*(1-(1-se^(1/m))^m)^2

initial values
    h = 199*exp(-(y-100)^2)-200

equations
    h : dy(k*(dy(h)+1)) = C*dt(h)

boundaries
    region 1
        start(0)
        line to (100) point value(h) = -1

front(h+150,1)

time 0 to 2

monitors
    for cycle=10
        elevation(c) from (100) to (0) as "capacitance"
        elevation(h) from (100) to (0) as "pressure"
        elevation(k) from (100) to (0) log as "conductivity"
        grid(y) from (100) to (0)

plots
     for t=0.001 0.01 0.1 1
        elevation(h) from (100) to (0) as "pressure"
        elevation(c) from (100) to (0) as "capacitance"
        elevation(k) from (100) to (0) log as "conductivity"
        grid(y) from (100) to (0)

end "Ei3lRSZqTDBZzDeztPYNiTiqENZ9nHT1nAgmUieNuLxI1J5Vjk76U5pnka/RE4zbPOcXTLS18e1eAJg1pl8cvfe3BacMTxNpXw6L4tGt2+GLimG+97lVmCk3YJXmUblL62NJLmL++YzilCqMj3ao9DnPOqp8Ffx3NouOkTN922Q"
