{ VECTOR_MAGNET_COIL.PDE  
  
  AXI-SYMMETRIC MAGNETIC FIELDS
 
  This example is a modification of MAGNET_COIL.PDE using vector variables.
  See that example for discussion of the problem formulation.
 
}
 
Title 'AXI-SYMMETRIC MAGNETIC FIELD -  Vector Variables'
 
Coordinates
    { Cylindrical coordinates, with cylinder axis along Cartesian X direction }
    xcylinder(Z,R)  
 
Variables
    A = vector(0,0,Aphi) { the azimuthal component of the  vector potential }
 
Definitions
    mu = 1                      { the permeability }
    rmu = 1/mu
    current = 0                 { the source defaults to zero }
    J = vector(0,0,current)
    Bz = dr(r*Aphi)/r
 
Initial Values
    Aphi = 2                    { unimportant unless mu varies with H }
 
Equations
    { FlexPDE expands CURL in proper coordinates }
    A : curl(rmu*curl(A)) = J 
 
Boundaries
    Region 1
      start(-10,0)
      value(Aphi) = 0               { specify A=0 along axis }
        line to (10,0)
      natural(Aphi) = 0             { H<dot>n = 0 on distant sphere }
        arc(center=0,0) angle 180 to close
 
    Region 2
      current = 10                       { override source value in the coil }
      start (-0.25,1)
        line to (0.25,1) to (0.25,1.5) to (-0.25,1.5) to close
 
Monitors
    contour(Bz) zoom(-2,0,4,4) as 'FLUX DENSITY B'
    contour(Aphi) as 'Potential'
 
Plots
    grid(z,r)
    contour(Bz)  as 'FLUX DENSITY B'
    contour(Bz) zoom(-2,0,4,4)  as 'FLUX DENSITY B'
    elevation(Aphi,dr(Aphi),Aphi/r,dr(Aphi)+Aphi/r,Aphi+r*dr(Aphi)) 
        from (0,0) to (0,1) as 'Bz'
    vector(dr(Aphi)+Aphi/r,-dz(Aphi)) as 'FLUX DENSITY B'
    vector(dr(Aphi)+Aphi/r,-dz(Aphi)) zoom(-2,0,4,4) as 'FLUX DENSITY B'
    contour(Aphi)  as 'MAGNETIC POTENTIAL'
    contour(Aphi) zoom(-2,0,4,4)  as 'MAGNETIC POTENTIAL'
    surface(Aphi)  as 'MAGNETIC POTENTIAL'  viewpoint (-1,1,30)
 
End "C68So7S2p/VUhu7pH406wQS9K3VSovdFFlmGEh/+bKNy7OtmewQfkYlUjXMXlbEse5syfyE3YeR1v8k1AN0YiDGbv/0xcKW8cKnGRNX+6lyiAK5aw/WH16n9xcxPPg/RkC8CLocb3bOV/8/RXnMI61dEGQMYsqwLFT6uepzcZqp"
