{ UNSCALED_Z.PDE  

  This is a reference problem for SCALED_Z.PDE.
  It solves for heatflow in a sandwich.

}

title 'Unscaled Z coordinate'

coordinates
    cartesian3

variables
    Tp

definitions
    long = 1/2  { thickness of the upper and lower layers }
    wide = 1
    w=0.01      { half-thickness of the imbedded slab }

    K  =0.1     { thermal conductivity -- modified later by layer }
    Q = 0       { Thermal source - modified later by layer }
    T0 = 0

initial values
    Tp = 0.

equations       { the heat equation }
  Tp:  dx(k*dx(Tp)) + dy(k*dy(Tp)) + dz(k*dz(Tp)) + Q = 0    

extrusion
  surface 'bottom' z = -long-w
    layer 'under'
  surface 'slab_bottom' z = -w
    layer 'slab'
  surface 'slab_top' z= w
    layer 'over'
  surface 'top' z= long+w

boundaries
  surface 'bottom'  load(Tp)=0.1*(T0-Tp)
  surface 'top'  load(Tp)=0.1*(T0-Tp)

  Region 1
    layer 2 
      Q = 100*exp(-x^2-y^2)   { a heat source in the slab layer only }
      k = 1         { redefine conductivity in layer 2 }
    start 'sidewall' (-wide,-wide)
      load(Tp) = 0
      layer 2 load(Tp) = 0.1*(T0-Tp)
      line to (wide,-wide)
           to (wide,wide)
           to (-wide,wide)
           to close

monitors
  contour(Tp) on z=0  as "XY Temp"
  contour(Tp) on x=0  as "YZ Temp"
  contour(Tp) on y=0  as "ZX Temp"

plots
  contour(Tp) on z=0  as "XY Temp"
  contour(Tp) on x=0  as "YZ Temp"
  contour(Tp) on y=0  as "ZX Temp"
  elevation(Tp) from (-wide,0,0) to (wide,0,0)  as "X-Axis Temp"
  elevation(Tp) from (0,-wide,0) to (0,wide,0)  as "Y-Axis Temp"
  elevation(Tp) from (0,0,-long-w) to (0,0,long+w)  as "Z-Axis Temp"
  vector(-k*dx(Tp),-k*dz(Tp)) on y=0 as "Flux on Y=0"
  vector(-k*dx(Tp),-k*dy(Tp)) on z=0 as "Flux on Z=0"
  elevation(k*dx(Tp)) from (-wide,0,0) to (wide,0,0)  as "Center X-Flux"
  elevation(k*dz(Tp)) from (0,0,-(long+w)) to (0,0,(long+w))  as "Center Z-Flux"
  SUMMARY   
    { form some integrals for comparison with Scaled_Z: }
    report(sintegral(-k*dz(Tp),'slab_top','slab'))
    report(sintegral(-k*dz(Tp),'slab_top','over'))
    report("--")
    report(sintegral(-normal(k*grad(Tp)),'sidewall','slab'))

end "GC/A4qxWkpau8R4zDh9XsV/EeTwpo2iAcBgzPAYiMyL8RzC6Cv9eP/k1034h+9jJT1+ZHkJPCPsONnHF0DY1p1bTVFDjQfnap7Q/QYGMMYAOV/+8j3+4uK0XHJtROBoFeb7Y/NrYrcXyaX6mnjYeu8WDsOz02qJBSm02pxIz+o+"
