
{ FILLEDGUIDE.PDE

   This problem models an inhomogeneously filled waveguide.
   See discussion in Help section "Electromagnetic Applications | Waveguides".
}

title "Filled Waveguide"

select
  modes = 8             { This is the number of Eigenvalues desired. }
  ngrid=30  regrid=off

variables
  hx,hy

definitions
  cm = 0.01   ! conversion from cm to meters
  b = 1*cm    ! box height
  L = 2*b     ! box width
  epsr
  epsr1=1
  epsr2=1.5
  ejump = 1/epsr2-1/epsr1   ! the boundary jump parameter
  eps0 = 8.85e-12
  mu0 = 4e-7*pi
  c =  1/sqrt(mu0*eps0)     ! light speed
  k0b = 4
  k0 = k0b/b
  k02 = k0^2                ! k0^2=omega^2*mu0*eps0

  curlh = dx(Hy)-dy(Hx)     ! terms used in equations and BCs
  divh = dx(Hx)+dy(Hy)

equations
  Hx:        dx(divh)/epsr - dy(curlh/epsr) + k02*Hx - lambda*Hx/epsr = 0
  Hy:        dx(curlh/epsr) + dy(divh)/epsr + k02*Hy - lambda*Hy/epsr = 0

boundaries
  region 1  epsr=epsr1
    start(0,0)
    natural(Hx) = 0  value(Hy)=0
    line to (L,0)
    value(Hx) = 0  value(Hy)=0  natural(Hy)=0
    line to (L,b)
    natural(Hx) = 0 value(Hy)=0
    line to (0,b)
    value(Hx) = 0  natural(Hy)=0
    line to close

  region 2  epsr=epsr2
    start(b,b)
    line to (0,b) to (0,0) to (b,0)
    natural(Hx) = normal(-ejump*divh,ejump*curlh)
    natural(Hy) = normal(-ejump*curlh,-ejump*divh)
    line to close

monitors
   contour(Hx) range=(-2,2)
   contour(Hy) range=(-2,2)

plots
   contour(Hx) range=(-2,2) report(k0b) report(sqrt(abs(lambda))/k0)
   surface(Hx) range=(-2,2) report(k0b) report(sqrt(abs(lambda))/k0)
   contour(Hy) range=(-2,2) report(k0b) report(sqrt(abs(lambda))/k0)
   surface(Hy) range=(-2,2) report(k0b) report(sqrt(abs(lambda))/k0)

summary  export
   report(k0b)
   report lambda
   report(sqrt(abs(lambda))/k0)

end "JAquzDuL0U15oF/o6I1YvIyWVnA+6uerHco/HdAgV947zeW5xpzBW8lm/MGYqv8pch3ZzS1wC0WgKkFIGL/UkJemL7WQ+Zdkg0u6JfvUHkgpoblY6gkT7XyrwUn0Qc3pQmleaxQwZA4Mw7gV1XZep9vXw7JAsMOgU35LbiAMJlo"
